@@ -35,7 +35,9 @@ t_fsbool is_directory(char *file);
 t_fsbool can_execute(char *file, uid_t uid, gid_t gid, t_groups *groups);
 int create_file(char *directory, mode_t mode, uid_t uid, gid_t gid);
 int create_directory(char *directory, mode_t mode, uid_t uid, gid_t gid);
-int  if_modified_since(int handle, char *datestr);
+int wipe_directory(char *directory, char *filter);
+int gzip_file(char *src, char *dest);
+int  if_modified_since(char *file, char *datestr);
 FILE *fopen_neighbour(char *filename, char *mode, char *neighbour);
 t_filelist *read_filelist(char *directory);
 t_filelist *sort_filelist(t_filelist *filelist);
